==> kzCodemirror-2_3_0.zip: kzCodemirror/config.php <==
<?php
if(!defined('PLX_ROOT')) { exit; }

# Control du token du formulaire
plxToken::validateFormToken($_POST);

$params = array(
	'cdn'					=> 'boolean',
	'theme'					=> 'string',
	'article'				=> 'numeric',
	'statique'				=> 'boolean',
	'comment'				=> 'boolean',
	'categorie'				=> 'boolean',
	'parametres_edittpl'	=> 'boolean',
	'parametres_plugincss'	=> 'boolean',
	'profil'				=> 'boolean',
	'lineNumbers'			=> 'boolean', // respecter la casse !
	'matchTags'				=> 'boolean',
	'lint'					=> 'boolean',
	'keymap'				=> 'string'
//	'emmet'					=> 'boolean'
);

$extensions = array(
	'theme'		=> 'css',
	'keymap'	=> 'js'
);

if(!empty($_POST)) {

	/* Traitement  du formulaire de configuration */
	foreach($params as $field=>$type) {
		$plxPlugin->delParam($field);
		if(!empty($_POST[$field])) {
			switch($type) {
				case 'boolean':
					$value = filter_input(INPUT_POST, $field, FILTER_VALIDATE_BOOLEAN) ? 1 : false;
					break;
				case 'numeric':
					if(is_array($_POST[$field])) {
						//$value = array_sum(filter_input_array(INPUT_POST, $field, FILTER_SANITIZE_NUMBER_INT));
						$value = array_sum($_POST[$field]);
					} else {
						$value = filter_input(INPUT_POST, $field, FILTER_SANITIZE_NUMBER_INT);
					}
					break;
				default:
					// Remplacer FILTER_SANITIZE_STRING en vérifiant que la valeur du $_POST est bien présente dans les optiosn du select correspondant
					$value = trim(filter_input(INPUT_POST, $field, FILTER_SANITIZE_STRING));
			}
			if(!empty($value)) {
				$plxPlugin->setParam($field, $value, ($type == 'boolean' ? 'numeric' : $type));
				continue;
			}
		}
	}
	$plxPlugin->saveParams();

	header('Location: parametres_plugin.php?p='.$plugin);
	exit;
}

$url_base = (empty($plxPlugin->local_path)) ? 'https://codemirror.net' : $plxPlugin->cm_url;

/* ------------ form starts here -----------------*/
?>

<div id="<?= $plugin; ?>-configuration">
	<form id="form_<?= $plugin; ?>" method="post">
		<div class="in-action-bar">
			<p>
				<input type="submit" value="<?= (defined('L_SAVE')) ? L_SAVE : L_ARTICLE_UPDATE_BUTTON; ?>" />
			</p>
		</div>
<?php

echo plxToken::getTokenPostMethod();

foreach($params as $field=>$type) {
	$value = $plxPlugin->getParam($field);
	if($field == 'article') {
		$plxPlugin->print_profils();
	}
?>
		<p>
			<label for="id_<?= $field; ?>"><?= $plxPlugin->lang('L_'.strtoupper($field)); ?></label>
<?php
		switch($type) {
			case 'boolean':
				if($field == 'cdn') {
					$checked = (empty($plxPlugin->local_path)) ? ' checked' : '';
				} else {
					$checked = (!empty($plxPlugin->getParam($field))) ? ' checked' : '';
				}
?>
			<input type="checkbox" id="id_<?= $field; ?>" name="<?= $field; ?>" value="1" <?= $checked; ?> />
<?php
				break;
			case 'numeric':
				switch($field) {
					case 'article':
						$plxPlugin->print_checkboxes_profils($field, $value);
						break;
					default:
						plxUtils::printInput($field, $value, 'number');
				}
				break;
			default:
				if(array_key_exists($field, $extensions)) {
					$plxPlugin->print_select($field, $value, $extensions[$field]);
				} else {
					plxUtils::printInput($field, $value);
				}
		}

		if($field == 'cdn') {
			if(empty(glob(__DIR__.'/codemirror*', GLOB_ONLYDIR))) {
				if(class_exists('ZipArchive') and function_exists('curl_init')) {
?>
			<input type="submit" id="id_download" name="download" value="<?php $plxPlugin->lang('L_DOWNLOAD'); ?>" />
<?php
				}
			} else {
?>
			<span title="<?php $plxPlugin->lang('L_LOCAL_LIBRARY_TITLE'); ?>"><?php $plxPlugin->lang('L_LOCAL_LIBRARY'); ?></span>
<?php
			}
		}
?>
		</p>
<?php
}
?>
	</form>
	<div>
		<textarea id="id_sandbox" name="sandbox" class="full-width"><?php readfile(__DIR__ .'/css/admin.css'); ?></textarea>
	</div>
</div>
<div id="<?= $plugin; ?>-promotion" class="action-bar">
	<p><a href="<?= $url_base; ?>" rel="noreferrer" target="_blank"><img src="<?= PLX_PLUGINS . $plugin; ?>/icon.png" alt="CodeMirror" /></a></p>
	<p><a href="<?= $url_base; ?>/doc/manual.html#addons" rel="noreferrer" target="_blank">Addons</a></p>
	<p><a href="<?= $url_base; ?>/demo/" rel="noreferrer" target="_blank">Demos</a></p>
</div>
<script type="text/javascript">
	(function() {
		'use strict';
<?php
	if(empty($plxPlugin->local_path)) {
?>

		// récupère tous les thèmes disponibles et raccourcis clavier de Codemirror sur Internet.
		const XHR = new XMLHttpRequest();
		XHR.onreadystatechange = function(event) {
			if(this.readyState === XMLHttpRequest.DONE) {
				if(this.status === 200) {
					const resp = JSON.parse(XHR.responseText);
					const version = resp.version

					const patterns = {
						theme	: /^theme\/([\w\-]+)\.css$/,
						keymap	: /^keymap\/([\w\-]+)\.js$/
					}
					for(var key in patterns) {
						const select = document.getElementById('id_' + key);
						const previous = select.value;
						const filenames = resp.assets[0].files.filter(function(item) {
							return item.match(patterns[key]);
						});
						filenames.forEach(function(item) {
							const value = item.replace(patterns[key], '$1');
							const option = document.createElement('OPTION');
							option.value = value;
							option.textContent = value.replace(/^([a-z])/, function(a) { return a.toUpperCase(); });
							option.selected = (value == previous);
							select.appendChild(option);
						});
					}
				}
			}
		}

		XHR.open('GET', '<?= $plxPlugin::API_CDNJS; ?>');
		XHR.send();
<?php
	}
?>

		const THEMES_SELECT = document.getElementById('id_theme');
		if(THEMES_SELECT != null) {
			THEMES_SELECT.addEventListener('change', function(event) {
				const theme = THEMES_SELECT.value;
				var stylesheet = document.head.querySelector('link[rel="alternate stylesheet"][title="' + theme + '"]');
				if(stylesheet == null) {
					const img = new Image();
					img.theme = theme;
					img.onloadend = function(event) {
						const links = document.head.querySelectorAll('link[rel="alternate stylesheet"]:not([disabled])');
						for(var i=0, iMax=links.length; i<iMax; i++) {
							links[i].disabled = true;
						}

						const theme = this.theme;
						stylesheet = document.createElement('LINK');
						stylesheet.type = 'text/css';
						stylesheet.rel = 'alternate stylesheet';
						stylesheet.title = theme;
						stylesheet.href = this.src;
						document.head.appendChild(stylesheet);

						document.styleSheets[document.styleSheets.length - 1].disabled = false;
						console.log('[<?= $plugin; ?>] theme : ' + theme + ' - stylesheets.length : ' + document.styleSheets.length);

					}
					img.src = '<?= $plxPlugin->cm_url; ?>/theme/' + theme + '.css';
				} else {
					stylesheet.disabled = false;
					console.log('theme : ' + theme + ' - stylesheets.length : ' + document.styleSheets.length + ' already uploaded');
				}

				editors.forEach(function(ed) {
					ed.setOption('theme', theme);
				});
			});
		}

		const CDN_CHECKBOX = document.getElementById('id_cdn');
		if(CDN_CHECKBOX != null) {
			CDN_CHECKBOX.addEventListener('change', function(event) {
				if(confirm('<?php $plxPlugin->lang('L_SAVE_CONFIG'); ?>')) {
					CDN_CHECKBOX.form.submit();
				}
			});
		}
	})();
</script>

==> kzCodemirror-2_4_0.zip: kzCodemirror/config.php <==
<?php
if(!defined('PLX_ROOT')) { exit; }

# Control du token du formulaire
plxToken::validateFormToken($_POST);

$params = array(
	'cdn'					=> 'boolean',
	'theme'					=> 'string',
	'article'				=> 'numeric',
	'statique'				=> 'boolean',
	'comment'				=> 'boolean',
	'categorie'				=> 'boolean',
	'parametres_edittpl'	=> 'boolean',
	'parametres_plugincss'	=> 'boolean',
	'profil'				=> 'boolean',
	'lineNumbers'			=> 'boolean', // respecter la casse !
	'matchTags'				=> 'boolean',
	'markdown'				=> 'boolean',
	'lint'					=> 'boolean',
	'keymap'				=> 'string',
//	'emmet'					=> 'boolean',
);

$extensions = array(
	'theme'		=> 'css',
	'keymap'	=> 'js'
);

if(!empty($_POST)) {

	/* Traitement  du formulaire de configuration */
	foreach($params as $field=>$type) {
		$plxPlugin->delParam($field);
		if(!empty($_POST[$field])) {
			switch($type) {
				case 'boolean':
					$value = filter_input(INPUT_POST, $field, FILTER_VALIDATE_BOOLEAN) ? 1 : false;
					break;
				case 'numeric':
					if(is_array($_POST[$field])) {
						//$value = array_sum(filter_input_array(INPUT_POST, $field, FILTER_SANITIZE_NUMBER_INT));
						$value = array_sum($_POST[$field]);
					} else {
						$value = filter_input(INPUT_POST, $field, FILTER_SANITIZE_NUMBER_INT);
					}
					break;
				default:
					// Remplacer FILTER_SANITIZE_STRING en vérifiant que la valeur du $_POST est bien présente dans les optiosn du select correspondant
					$value = trim(filter_input(INPUT_POST, $field, FILTER_SANITIZE_STRING));
			}
			if(!empty($value)) {
				$plxPlugin->setParam($field, $value, ($type == 'boolean' ? 'numeric' : $type));
				continue;
			}
		}
	}
	$plxPlugin->saveParams();

	header('Location: parametres_plugin.php?p=' . $plugin);
	exit;
}

$url_base = (empty($plxPlugin->local_path)) ? 'https://codemirror.net' : $plxPlugin->cm_url;

/* ------------ form starts here -----------------*/
?>
<!-- <?= $plugin ?> plugin -->
<?php
# activation script javascript pour démonstration du thème choisi
$plxPlugin->config = true;

if(empty($plxAdmin->plxPlugins->aPlugins[$plugin])) {
	# Plugin désactivé. On l'active
	$plxAdmin->plxPlugins->aPlugins[$plugin] = $plxPlugin;
	$plxAdmin->plxPlugins->aHooks = array_merge_recursive($plxAdmin->plxPlugins->aHooks, $plxPlugin->getHooks());
	$plxPlugin->disabled = true;
}
?>
<div id="<?= $plugin; ?>-configuration">
	<form id="form_<?= $plugin; ?>" method="post">
		<div class="in-action-bar">
			<p>
				<input type="submit" value="<?= (defined('L_SAVE')) ? L_SAVE : L_ARTICLE_UPDATE_BUTTON; ?>" />
			</p>
		</div>
<?php

echo plxToken::getTokenPostMethod();

foreach($params as $field=>$type) {
	$value = $plxPlugin->getParam($field);
	if($field == 'article') {
		$plxPlugin->print_profils();
	}
?>
		<p>
			<label for="id_<?= $field; ?>"><?= $plxPlugin->lang('L_'.strtoupper($field)); ?></label>
<?php
		switch($type) {
			case 'boolean':
				if($field == 'cdn') {
					$checked = (empty($plxPlugin->local_path)) ? ' checked' : '';
				} else {
					$checked = (!empty($plxPlugin->getParam($field))) ? ' checked' : '';
				}
?>
			<input type="checkbox" id="id_<?= $field; ?>" name="<?= $field; ?>" value="1" <?= $checked; ?> />
<?php
				break;
			case 'numeric':
				switch($field) {
					case 'article':
						$plxPlugin->print_checkboxes_profils($field, $value);
						break;
					default:
						plxUtils::printInput($field, $value, 'number');
				}
				break;
			default:
				if(array_key_exists($field, $extensions)) {
					$plxPlugin->print_select($field, $value, $extensions[$field]);
				} else {
					plxUtils::printInput($field, $value);
				}
		}

		if($field == 'cdn') {
			if(empty(glob(__DIR__ . '/codemirror*', GLOB_ONLYDIR))) {
				if(class_exists('ZipArchive') and function_exists('curl_init')) {
?>
			<input type="submit" id="id_download" name="download" value="<?php $plxPlugin->lang('L_DOWNLOAD'); ?>" />
<?php
				}
			} else {
?>
			<span title="<?php $plxPlugin->lang('L_LOCAL_LIBRARY_TITLE'); ?>"><?php $plxPlugin->lang('L_LOCAL_LIBRARY'); ?></span>
<?php
			}
		}
?>
		</p>
<?php
}
?>
	</form>
	<div>
<?php
if(!$plxPlugin->disabled) {
?>
		<textarea id="id_sandbox" name="sandbox" class="full-width"><?php readfile(__DIR__ .'/css/admin.css'); ?></textarea>
<?php
}
?>
	</div>
</div>
<div id="<?= $plugin; ?>-promotion" class="action-bar">
	<p><a href="<?= $url_base; ?>" rel="noreferrer" target="_blank"><img src="<?= PLX_PLUGINS . $plugin; ?>/icon.png" alt="CodeMirror" /></a></p>
	<p><a href="<?= $url_base; ?>/doc/manual.html#addons" rel="noreferrer" target="_blank">Addons</a></p>
	<p><a href="<?= $url_base; ?>/demo/" rel="noreferrer" target="_blank">Demos</a></p>
</div>
<script type="text/javascript">
	(function() {
		'use strict';
<?php
	if(empty($plxPlugin->local_path)) {
?>

		// récupère tous les thèmes disponibles et raccourcis clavier de Codemirror sur Internet.
		const XHR = new XMLHttpRequest();
		XHR.onreadystatechange = function(event) {
			if(this.readyState === XMLHttpRequest.DONE) {
				if(this.status === 200) {
					const resp = JSON.parse(XHR.responseText);
					const version = resp.version

					const patterns = {
						theme	: /^theme\/([\w\-]+)\.css$/,
						keymap	: /^keymap\/([\w\-]+)\.js$/
					}
					for(var key in patterns) {
						const select = document.getElementById('id_' + key);
						const previous = select.value;
						const filenames = resp.assets[0].files.filter(function(item) {
							return item.match(patterns[key]);
						});
						filenames.forEach(function(item) {
							const value = item.replace(patterns[key], '$1');
							const option = document.createElement('OPTION');
							option.value = value;
							option.textContent = value.replace(/^([a-z])/, function(a) { return a.toUpperCase(); });
							option.selected = (value == previous);
							select.appendChild(option);
						});
					}
				}
			}
		}

		XHR.open('GET', '<?= $plxPlugin::API_CDNJS; ?>');
		XHR.send();
<?php
	}
?>
		const CDN_CHECKBOX = document.getElementById('id_cdn');
		if(CDN_CHECKBOX != null) {
			CDN_CHECKBOX.addEventListener('change', function(event) {
				if(confirm('<?php $plxPlugin->lang('L_SAVE_CONFIG'); ?>')) {
					CDN_CHECKBOX.form.submit();
				}
			});
		}
	})();
</script>
<!-- End of <?= $plugin ?> plugin configuration -->
